@@ -10,7 +10,7 @@ function(nstates,ncases,formula=~1,data=NULL,values=NULL, ...) {
 		initModel <- transInit(~1,data=data.frame(rep(1,ncases)),nst=nstates,family=multinomial(link="identity"),pstart=values)
 	} else {
 		if(is.null(data)) {
-			stop("'Argument initdata missing while the init model is non-trivial")
+			stop("Argument 'initdata' missing with non-trivial prior model")
 		} else {
 			initModel <- transInit(formula,data=data,nst=nstates,family=multinomial(),pstart=values)
 		}	
