@@ -7,23 +7,19 @@ function(response,data=NULL,nstates,family,values=NULL,prob=TRUE,...) {
 		
 	# univariate response data
 	if(class(resp)=="formula") {
-		nresp <- 1
-		for(i in 1:nstates) {
-			response[[i]] <- list()
-			response[[i]][[1]] <- GLMresponse(resp,data=data,family=family)
-			nresppars <- nresppars + npar(response[[i]][[1]])
-		}
+		resp <- list(resp)
+		family <- list(family)
 	}
 	
-	# multivariate response data
-	if(is.list(resp)) {
-		nresp <- length(resp)
-		for(i in 1:nstates) {
-			response[[i]] <- list()
-			for(j in 1:nresp) {
-				response[[i]][[j]] <- GLMresponse(resp[[j]],data=data,family=family[[j]])
-				nresppars <- nresppars + npar(response[[i]][[j]])
-			}
+	if(!(length(resp)==length(family))) stop("Length of 'response' list and 'family' list do not match")
+	
+	# make response model
+	nresp <- length(resp)
+	for(i in 1:nstates) {
+		response[[i]] <- list()
+		for(j in 1:nresp) {
+			response[[i]][[j]] <- GLMresponse(resp[[j]],data=data,family=family[[j]])
+			nresppars <- nresppars + npar(response[[i]][[j]])
 		}
 	}
 	
@@ -33,7 +29,7 @@ function(response,data=NULL,nstates,family,values=NULL,prob=TRUE,...) {
 		for(i in 1:nstates) {
 			for(j in 1:nresp) {
 				bp <- npar(response[[i]][[j]])
-				response[[i]][[j]] <- setpars(response[[i]][[j]],val=values[1:bp],prob=prob)
+				response[[i]][[j]] <- GLMresponse(resp[[j]],data=data,family=family[[j]],pstart=values[1:bp],prob=prob)
 				bp <- bp+1
 				values <- values[bp:length(values)]
 			}
